package de.intevation.flys.artifacts.states.fixation;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.ProtocolUtils;
import de.intevation.artifactdatabase.data.StateData;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.resources.Resources;
import de.intevation.flys.artifacts.states.DefaultState;


/**
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class FixationSelect extends DefaultState {

    /** The logger used in this class. */
    private static Logger logger = Logger.getLogger(FixationSelect.class);


    /** Constant value for the default fixation calculation. */
    public static final String CALCULATION_DEFAULT = "calc.fixation.default";

    /** Constant value for the volmer fixation analysis. */
    public static final String CALCULATION_VOLMER = "calc.fixation.volmer";

    /** An Array that holds all available calculation modes.*/
    public static final String[] CALCULATIONS = {
        CALCULATION_DEFAULT,
        CALCULATION_VOLMER
    };

    /** Error message that is thrown if no mode has been chosen. */
    public static final String ERROR_NO_CALCULATION_MODE =
        "error_feed_no_calculation_mode";

    /** Error message that is thrown if an invalid calculation mode has been
     * chosen. */
    public static  final String ERROR_INVALID_CALCULATION_MODE =
        "error_feed_invalid_calculation_mode";


    /**
     * The default constructor that initializes an empty State object.
     */
    public FixationSelect() {
    }


    @Override
    protected Element[] createItems(
        XMLUtils.ElementCreator ec,
        Artifact                artifact,
        String                  name,
        CallContext             context)
    {
        CallMeta meta = context.getMeta();
        Element[] calculations = new Element[CALCULATIONS.length];

        for (int i = 0; i < CALCULATIONS.length; i++) {
            String calc = CALCULATIONS[i];
            calculations[i] = createItem(
                ec,
                new String[] {Resources.getMsg(meta, calc, calc), calc});
        }
        return calculations;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
